# OE Common

Simple module with some functions such as generate password (get_random_string), fix unicode strings, size converter, dynamic console, read/write speed checker, etc.
## Prerequisites

	- Python3.7 or newer

## Installion
$ python3 -m pip install oe_common<br /><br />
**OR**<br /><br />
$ python3 -m pip install git+https://github.com/jok4r/oe_common.git

## Functions
- fix_block_encoding_errors
- fix_unicode_string
- convert_size
- get_rnd_string
- genarate_password
- check_create_dir

## Classes
- DinConsole
    - clear
    - stay
    - update

- SpeedChecker
    - get_speed